@@ -119,7 +119,7 @@ def install(email, file, path, user, schedule):
 @cli.command()
 def run(email, file, path):
     global merged_config
-    files_to_process = glob.glob(path)
+    files_to_process = sorted(glob.glob(path), key=os.path.getmtime)
 
     if len(files_to_process) == 0:
         click.echo(f'WARNING: path "{path}" is either invalid or has no files to process')
